pub struct ShowCommand { /* private fields */ }Expand description
Command for inspecting current state or a saved plan.
With -json, returns structured data about the current state or a
saved plan file.
use terraform_wrapper::{Terraform, TerraformCommand};
use terraform_wrapper::commands::show::{ShowCommand, ShowResult};
let tf = Terraform::builder().working_dir("/tmp/infra").build()?;
// Show current state
let result = ShowCommand::new().execute(&tf).await?;
// Show a saved plan
let result = ShowCommand::new()
.plan_file("tfplan")
.execute(&tf)
.await?;Implementations
Sourceimpl ShowCommand
impl ShowCommand